@@ -19,9 +19,9 @@ BUG_RELATED_LABELS = {'bug', 'Bug', 'bug :bug:', 'Bug - Medium', 'Bug - Low', 'B
                       'kind/bug', 'kind/bugs', 'bug/bugfix', 'bugfix', 'critical-bug', '01 type: bug', 'bug_report',
                       'minor-bug'}
 
-
 FIXING_COMMITS_REGEX = r'(bug|fix|error|crash|problem|fail|defect|patch)'
 
+
 class RepositoryMiner:
     """
     This class is responsible for mining the history of a repository to collect defect-prone and defect-free blueprints.
@@ -48,6 +48,7 @@ class RepositoryMiner:
         self.repo_name = repo_name
         self.branch = branch
 
+        self.exclude_commits = set()  # This is to set up commits known to be non-fixing in advance
         self.fixing_commits = list()
         self.fixing_files = list()
 
@@ -122,6 +123,10 @@ class RepositoryMiner:
         for label in labels:
             for issue in self.get_closed_issues(label):
                 for e in issue.get_events():
+
+                    if e.commit_id in self.exclude_commits or e.commit_id in self.fixing_commits:
+                        continue
+
                     is_merged = e.event.lower() == 'merged'
                     is_closed = e.event.lower() == 'closed'
 
@@ -154,6 +159,9 @@ class RepositoryMiner:
 
         for commit in RepositoryMining(self.path_to_repo, only_in_branch=self.branch).traverse_commits():
 
+            if (commit.hash in self.exclude_commits) or (commit.hash in self.fixing_commits):
+                continue
+
             # Remove words ending with 'bug' or 'fix' (e.g., 'debug' and 'prefix') from the commit message
             p = re.compile(r'(\w+(bug|fix)\w)*', re.IGNORECASE)
             msg = commit.msg
